/*
	relay2cl.cpp
	Library for controlling 2 coil latching relays.
	Pietro Maoddi // 21.02.2017 // pietro.maoddi@gmail.com
*/

#include <Arduino.h>
#include "relay2cl.h"

TwoCoilRelay::TwoCoilRelay(uint8_t pin1, uint8_t pin2, uint16_t hold_time, bool activeLow)
{
	// Control pins
	this->pin1 = pin1;
	this->pin2 = pin2;
	
	// Set control pin modes
	pinMode(pin1, OUTPUT);
	pinMode(pin2, OUTPUT);
	
	// Control values
	if (activeLow)
	{
		ACTIVE = LOW;
		INACTIVE = HIGH;
	}
	else
	{
		ACTIVE = HIGH;
		INACTIVE = LOW;
	}
	
	// Deactivate coils
	digitalWrite(pin1, INACTIVE);
	digitalWrite(pin2, INACTIVE);
	
	// Hold time (ms)
	this->holdTime = hold_time;
}

void TwoCoilRelay::Select(uint8_t input)
{
	if (input == 0)
	{
		digitalWrite(pin1, ACTIVE);
		delay(holdTime);
		digitalWrite(pin1, INACTIVE);
	}
	else
	{
		digitalWrite(pin2, ACTIVE);
		delay(holdTime);
		digitalWrite(pin2, INACTIVE);
	}
}