/*
	spiswitch.cpp
	Library for ADG1414 switch arrays.
	Pietro Maoddi // 28.02.2017 // pietro.maoddi@gmail.com
*/

#include <Arduino.h>
#include <SPI.h>
#include "spiswitch.h"

SPISwitch::SPISwitch(SPISettings spiSet, uint8_t ss, uint8_t rst, uint8_t n)
{
	settings = spiSet;
	
	pinSS = ss;
	pinReset = rst;
	
	nChips = n;
	switchState = malloc(nChips * sizeof(uint8_t));
	for (uint8_t i=0; i<nChips; ++i)
	{
		switchState[i] = 0x00;
	}
	
	pinMode(pinSS, OUTPUT);
	pinMode(pinReset, OUTPUT);
	
	digitalWrite(pinSS, HIGH);
	digitalWrite(pinReset, HIGH);
	
	SPI.begin();
}

SPISwitch::Reset()
{
	for (uint8_t i=0; i<nChips; ++i)
	{
		switchState[i] = 0x00;
	}
	
	SPI.end();
	digitalWrite(pinSS, LOW);
	
	digitalWrite(pinReset, LOW);
	digitalWrite(pinReset, HIGH);
	
	digitalWrite(pinSS, HIGH);
	SPI.begin();
}

SPISwitch::Set(uint8_t sw, bool state)
{
	uint8_t chip, bit;
	uint8_t val, tmp;
	
	chip = (nChips - 1) - sw/8;
	bit = sw%8;
	
	if (state) val = 0x01;
	else val = 0x00;
	
	tmp = switchState[chip];
	tmp ^= (-val ^ tmp) & (1 << bit);
	switchState[chip] = tmp;
}

SPISwitch::SendConfiguration()
{
	SPI.beginTransaction(settings);
	digitalWrite(pinSS, LOW);
	SPI.transfer(switchState, nChips);
	digitalWrite(pinSS, HIGH);
	SPI.endTransaction();
}

SPISwitch::PrintConfiguration()
{
	char buffer[9];
	for (uint8_t i=0; i<nChips; ++i)
	{
		sprintf(buffer, "%02X", switchState[i]);
		Serial.print(buffer);
	}
	Serial.println("");
}

